.. _code_of_conduct_page:

=================
Code of Conduct
=================

All participants in the `k-diagram` project (including maintainers,
contributors, and users interacting in project spaces like the issue
tracker) are expected to adhere to the following Code of Conduct.

This code is adapted from the Contributor Covenant, version 2.1.

.. literalinclude:: ../../CODE_OF_CONDUCT.md
   :language: markdown
   :linenos: